=============================
django-redis-views
=============================

.. image:: https://badge.fury.io/py/django-redis-views.png
    :target: https://badge.fury.io/py/django-redis-views

.. image:: https://travis-ci.org/kevinlondon/django-redis-views.png?branch=master
    :target: https://travis-ci.org/kevinlondon/django-redis-views

An implementation of the server-side component for Lightning Fast SPA deploys.

Documentation
-------------

The full documentation is at https://django-redis-views.readthedocs.org.

Quickstart
----------

Install django-redis-views::

    pip install django-redis-views

Then use it in a project::

    import redis_views

Features
--------

* TODO

Cookiecutter Tools Used in Making This Package
----------------------------------------------

*  cookiecutter
*  cookiecutter-djangopackage
